OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Senha errada",
    "The new password can not be the same as the previous one" : "A nova senha não pode ser igual a anterior",
    "No user supplied" : "Nenhum usuário fornecido",
    "Authentication error" : "Erro de autenticação",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor, informe uma senha de recuperação administrativa; de outra forma, todos os dados do usuário serão perdidos.",
    "Wrong admin recovery password. Please check the password and try again." : "Senha de recuperação do administrador errada. Por favor verifique a senha e tente novamente.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Back-end não suporta alteração de senha, mas a chave de criptografia de usuários foi atualizado com sucesso....",
    "Unable to change password" : "Impossível modificar senha",
    "%s password changed successfully" : "%s senha alterada com sucesso",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar e-mail de redefinição. Por favor, contate o administrador.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando e atualizando aplicativos via app store ou Núvem Compartilhada Federada",
    "Federated Cloud Sharing" : "Compartilhamento de Nuvem Conglomerada",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL está usando um desatualizado %s versão (%s). Por favor, atualize seu sistema operacional ou recursos como %s não vai funcionar de forma confiável.",
    "A problem occurred, please check your log files (Error: %s)" : "Ocorreu um problema enquanto verificava seus arquivos de log (Erro: %s)",
    "Migration Completed" : "Migração Concluida",
    "Group already exists." : "O Grupo já existe.",
    "Unable to add group." : "Não é possível adicionar grupo.",
    "Unable to delete group." : "Não é possível excluir grupo.",
    "log-level out of allowed range" : "log-nível acima do permitido",
    "Saved" : "Salvo",
    "test email settings" : "testar configurações de email",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor, revise suas configurações. (Erro: %s)",
    "Email sent" : "E-mail enviado",
    "You need to set your user email before being able to send test emails." : "Você precisa configurar seu e-mail de usuário antes de ser capaz de enviar e-mails de teste.",
    "Couldn't change the email address because the user does not exist" : "Não foi possível alterar o endereço de e-mail porque o usuário não existe",
    "Couldn't change the email address because the token is invalid" : "Não foi possível alterar o endereço de e-mail porque o token é inválido",
    "Invalid mail address" : "Endereço de e-mail inválido",
    "A user with that name already exists." : "Um usuário com esse nome já existe.",
    "Unable to create user." : "Não é possível criar usuário.",
    "Your %s account was created" : "Sua conta %s foi criada",
    "Unable to delete user." : "Não é possível excluir usuário.",
    "Forbidden" : "Proibido",
    "Invalid user" : "Usuário inválido",
    "Unable to change mail address" : "Não é possível trocar o endereço de email",
    "Email has been changed successfully." : "O e-mail foi alterado com sucesso.",
    "An email has been sent to this address for confirmation" : "Um de email foi enviado para este endereço para confirmação",
    "No email was sent because you already sent one recently. Please try again later." : "Nenhum email foi enviado porque você já enviou um recentemente. Por favor, tente novamente mais tarde.",
    "Your full name has been changed." : "Seu nome completo foi alterado.",
    "Unable to change full name" : "Não é possível alterar o nome completo",
    "%s email address confirm" : "%s endereço de e-mail confirmar",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Não foi possível enviar email de confirmação de alteração de endereço. Entre em contato com o administrador.",
    "%s email address changed successfully" : "O endereço de e-mail %s foi alterado com êxito",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Não foi possível enviar email de notificação de alteração de endereço. Entre em contato com o administrador.",
    "Unable to enable/disable user." : "Não foi possível habilitar/desabilitar usuário",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "Idioma alterado",
    "Invalid request" : "Pedido inválido",
    "Admins can't remove themself from the admin group" : "Administradores não pode remover a si mesmos do grupo de administração",
    "Unknown user" : "Usuário desconhecido",
    "Couldn't remove app." : "Não foi possível remover aplicativos.",
    "Official" : "Oficial",
    "Approved" : "Aprovado",
    "All" : "Todos",
    "Enabled" : "Habilitado",
    "Not enabled" : "Desabilitado",
    "No apps found for your version" : "Nenhum aplicativo encontrados para a sua versão",
    "The app will be downloaded from the app store" : "O aplicativo será baixado na App Store",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplicativos oficiais são desenvolvidos por e dentro da comunidade ownCloud. Eles oferecem funcionalidade central para ownCloud e estão prontos para uso em produção.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Aplicativos aprovados são desenvolvidos pelos desenvolvedores confiáveis e passaram por uma verificação de segurança superficial. Eles são ativamente mantidos em um repositório de código aberto e seus mantenedores consideram que eles para sejam estáveis para um casual uso normal.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Este aplicativo não foi verificado para as questões de segurança e é novo ou conhecido por ser instável. Instale por seu próprio risco.",
    "Please wait...." : "Por favor, aguarde...",
    "Error while disabling app" : "Erro enquanto desabilitava o aplicativo",
    "Disable" : "Desabilitar",
    "Enable" : "Habilitar",
    "Error while enabling app" : "Erro enquanto habilitava o aplicativo",
    "Error: this app cannot be enabled because it makes the server unstable" : "Erro: este aplicativo não pode ser habilitado porque faz com que o servidor fique instável",
    "Error: could not disable broken app" : "Erro: Não foi possível desativar o aplicativo quebrado",
    "Error while disabling broken app" : "Erro ao desativar aplicativo quebrado",
    "Updating...." : "Atualizando...",
    "Error while updating app" : "Erro ao atualizar aplicativo",
    "Updated" : "Atualizado",
    "Uninstalling ...." : "Desinstalando ...",
    "Error while uninstalling app" : "Erro enquanto desinstalava aplicativo",
    "Uninstall" : "Desinstalar",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "O aplicativo foi habilitado, mas precisa ser atualizado. Você será redirecionado para a página de atualização em 5 segundos.",
    "App update" : "Atualização de aplicativo",
    "Experimental" : "Experimental",
    "No apps found for {query}" : "Nenhum aplicativo encontrados para {query}",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Você tem certeza que você quer adicionar \"{domain}\" como domínio confiável?",
    "Add trusted domain" : "Adicionar domínio confiável",
    "Migration in progress. Please wait until the migration is finished" : "Migração em progresso. Por favor aguarde até que a migração seja finalizada",
    "Migration started …" : "Migração iniciada ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ocorreu um erro. Por favor envie um certificado ASCII-encoded PEM",
    "Valid until {date}" : "Vádido até {date}",
    "Delete" : "Excluir",
    "Disconnect" : "Desconectar",
    "Error while loading browser sessions and device tokens" : "Erro durante carregamento de sessões do navegador e tokens de dispositivos",
    "Error while creating device token" : "Erro ao criar token de dispositivo",
    "Error while deleting the token" : "Erro ao excluir o token",
    "Sending..." : "Enviando...",
    "Failed to change the email address." : "Falha ao alterar o endereço de e-mail.",
    "Email changed successfully." : "E-mail alterado com sucesso.",
    "An error occurred: {message}" : "Ocorreu um erro: {message}",
    "Select a profile picture" : "Selecione uma imagem para o perfil",
    "Very weak password" : "Senha muito fraca",
    "Weak password" : "Senha fraca",
    "So-so password" : "Senha mais ou menos",
    "Good password" : "Boa senha",
    "Strong password" : "Senha forte",
    "Groups" : "Grupos",
    "Unable to delete {objName}" : "Não é possível excluir {objName}",
    "Error creating group: {message}" : "Erro criando o grupo: {message}",
    "A valid group name must be provided" : "Um nome de grupo válido deve ser fornecido",
    "deleted {groupName}" : "eliminado {groupName}",
    "undo" : "desfazer",
    "never" : "nunca",
    "deleted {userName}" : "eliminado {userName}",
    "add group" : "adicionar grupo",
    "Invalid quota value \"{val}\"" : "Valor inválido de quota \"{val}\"",
    "enabled" : "habilitado",
    "disabled" : "desabilitado",
    "User {uid} has been {state}!" : "O usuário {uid} foi {state}!",
    "no group" : "nenhum grupo",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Trocar a senha irá resultar em perda de dados, porque recuperação de dados não está disponível para este usuário",
    "Password successfully changed" : "Senha modificada com sucesso",
    "A valid username must be provided" : "Forneça um nome de usuário válido",
    "Error creating user: {message}" : "Erro criando o usuário: {message}",
    "A valid password must be provided" : "Forneça uma senha válida",
    "A valid email must be provided" : "Deve ser informado um e-mail válido",
    "Use the following link to confirm your changes to the email address: {link}" : "Use o seguinte link para confirmar suas alterações no endereço de e-mail: {link}",
    "Email address changed to {mailAddress} successfully." : "E-mail alterado para {mailAddress} com sucesso.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Olá,<br><br>somente para lembrar que agora você tem uma conta %s.<br><br>Seu nome de usuário é: %s<br>Acesse em: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Saudações!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Olá,\n\nsomente para lembrar que agora você tem uma conta %s.\n\nSeu nome de usuário é: %s\nAcesse em: %s\n\n",
    "User documentation" : "Documentação do usuário",
    "Administrator documentation" : "Documentação do administrador",
    "Online documentation" : "Documentação online",
    "Forum" : "Fórum",
    "Issue tracker" : "Rastreador de tópicos",
    "Commercial support" : "Suporte comercial",
    "Apps Management" : "Gerenciamento de aplicativos",
    "Developer documentation" : "Documentação do desenvolvedor",
    "by %s" : "por %s",
    "%s-licensed" : "%s-licenciado",
    "Documentation:" : "Documentação:",
    "Admin documentation" : "Documentação para Administração",
    "Visit website" : "Visitar website",
    "Report a bug" : "Registrar um bug",
    "Show description …" : "Mostrar descrição ...",
    "Hide description …" : "Esconder descrição ...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Este aplicativo não tem atribuída nenhuma  versão ownCloud mínima. Isto será um erro no ownCloud 11 e posterior.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Este aplicativo não tem atribuída nenhuma  versão ownCloud máxima. Isto será um erro no ownCloud 11 e posterior.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Este aplicativo não pode ser instalado porque as seguintes dependências não forão cumpridas:",
    "Enable only for specific groups" : "Ativar apenas para grupos específicos",
    "Uninstall App" : "Desinstalar Aplicativo",
    "Show enabled apps" : "Mostrar aplicativos habilitados",
    "Show disabled apps" : "Mostrar aplicativos desabilitados",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Última execução do trabalho cron: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Última execução do trabalho cron: %s. Algo parece errado.",
    "Cron was not executed yet!" : "Cron não foi executado ainda!",
    "Open documentation" : "Abrir documentação",
    "Execute one task with each page loaded" : "Execute uma tarefa com cada página carregada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php está registrado no serviço webcron para chamar cron.php a cada 15 minutos sobre http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Usar o serviço cron do sistema para chamar o arquivo cron.php cada 15 minutos.",
    "SSL Root Certificates" : "Certificados Raiz SSL",
    "Common Name" : "Nome",
    "Valid until" : "Válido até",
    "Issued By" : "Emitido Por",
    "Valid until %s" : "Válido até %s",
    "Import root certificate" : "Importar certificado raiz",
    "Server-side encryption" : "Criptografia do lado do servidor",
    "Enable server-side encryption" : "Habilitar a Criptografia do Lado do Servidor",
    "Please read carefully before activating server-side encryption: " : "Por favor, leia com atenção antes de ativar a criptografia do lado do servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez que a criptografia é ativada, todos os arquivos carregados para o servidor a partir desse ponto em diante serão criptografados e estarão disponíveis no servidor. Só será possível desativar a criptografia em uma data posterior, se o módulo de criptografia ativo suporta essa função, e todas as pré-condições sejam cumpridas(por exemplo, definindo uma chave de recuperação).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Criptografia por si só não garante a segurança do sistema. Por favor, consulte a documentação ownCloud para obter mais informações sobre como o aplicativo de criptografia funciona, e os casos de uso suportados.",
    "Be aware that encryption always increases the file size." : "Esteja ciente de que a criptografia sempre aumenta o tamanho do arquivo.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar backups regulares dos seus dados, em caso de criptografia certifique-se de fazer backup das chaves de criptografia, juntamente com os seus dados.",
    "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: Você realmente quer ativar a criptografia?",
    "Enable encryption" : "Ativar criptografia",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de criptografia carregado, por favor, ative um módulo de criptografia no menu de aplicativos.",
    "Select default encryption module:" : "Selecione o módulo de criptografia padrão:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Você precisa migrar suas chaves de criptografia a partir da antiga criptografia (ownCloud <= 8,0) para a nova. Ative o \"módulo de criptografia padrão\" e execute 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Você precisa migrar suas chaves de criptografia a partir da antiga criptografia (ownCloud <= 8,0) para a nova.",
    "Start migration" : "Iniciar migração",
    "Sharing" : "Compartilhamento",
    "Allow apps to use the Share API" : "Permitir que aplicativos usem a API de Compartilhamento",
    "Allow users to share via link" : "Permitir que os usuários compartilhem por link",
    "Allow public uploads" : "Permitir envio público",
    "Enforce password protection" : "Reforce a proteção por senha",
    "Set default expiration date" : "Configurar a data de expiração",
    "Allow users to send mail notification for shared files" : "Permitir aos usuários enviar notificação de email para arquivos compartilhados",
    "Allow users to share file via social media" : "Permite que usuários compartilhem arquivos via mídia social",
    "Expire after " : "Expirar depois de",
    "days" : "dias",
    "Enforce expiration date" : "Fazer cumprir a data de expiração",
    "Allow resharing" : "Permitir recompartilhamento",
    "Allow sharing with groups" : "Permitir o compartilhamento com grupos",
    "Restrict users to only share with users in their groups" : "Restringir os usuários a compartilhar somente com os usuários em seus grupos",
    "Allow users to send mail notification for shared files to other users" : "Permitir aos usuários enviar notificação de email de arquivos compartilhados para outros usuários",
    "Exclude groups from sharing" : "Excluir grupos de compartilhamento",
    "These groups will still be able to receive shares, but not to initiate them." : "Esses grupos ainda serão capazes de receber compartilhamentos, mas não para iniciá-los.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Permitir autocompletar nome de usuário no diálogo de compartilhamento. Se isto estiver desativado o nome de usuário completo precisa ser inserido.",
    "Restrict enumeration to group members" : "Restringir a enumeração aos membros do grupo",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tudo (questões fatais, erros, avisos, informações, depuração)",
    "Info, warnings, errors and fatal issues" : "Informações, avisos, erros e problemas fatais",
    "Warnings, errors and fatal issues" : "Avisos, erros e problemas fatais",
    "Errors and fatal issues" : "Erros e problemas fatais",
    "Fatal issues only" : "Somente questões fatais",
    "Log" : "Registro",
    "What to log" : "O que colocar no log",
    "Download logfile (%s)" : "Baixar o arquivo de log (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "O arquivo de log é maior que 100 MB. Baixar esse arquivo requer algum tempo!",
    "None" : "Nada",
    "Login" : "Login",
    "Plain" : "Plano",
    "NT LAN Manager" : "Gerenciador NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor de Email",
    "This is used for sending out notifications." : "Isto é usado para o envio de notificações.",
    "Send mode" : "Modo enviar",
    "Encryption" : "Criptografia",
    "From address" : "Do Endereço",
    "mail" : "email",
    "Authentication method" : "Método de autenticação",
    "Authentication required" : "Autenticação é requerida",
    "Server address" : "Endereço do servidor",
    "Port" : "Porta",
    "Credentials" : "Credenciais",
    "SMTP Username" : "Nome do Usuário SMTP",
    "SMTP Password" : "Senha SMTP",
    "Store credentials" : "Armazenar credenciais",
    "Test email settings" : "Configurações de e-mail de teste",
    "Send email" : "Enviar email",
    "Security & setup warnings" : "Segurança & avisos de configuração",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parecem esta configurado corretamente para consultar as variáveis de ambiente do sistema. O teste com getenv(\"PATH\") só retorna uma resposta vazia.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Por favor verifique a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação de instalação ↗</a> para notas configuração do PHP e a configuração do PHP do seu servidor, especialmente quando se utiliza php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Somente-Leitura foi habilitada. Isso impede que algumas configurações sejam definidas via a interface web. Além disso, o arquivo precisa ter permissão de escrita manual para cada atualização.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP é, aparentemente, a configuração para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por uma cache/acelerador, como Zend OPcache ou eAccelerator.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Seu banco de dados não está sendo executado com \"READ COMMITTED\" nível de isolamento da transação. Isto pode causar problemas quando várias ações são executadas em paralelo.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s abaixo da versão %2$s está instalado, por razões de estabilidade e desempenho recomendamos a atualização para uma nova versão %1$s.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "O módulo PHP 'fileinfo' está faltando. Recomendamos que ative este módulo para obter uma melhor detecção do tipo de mídia (mime-type).",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivo transacional está desativado, isso pode levar a problemas com as condições de corrida. Ativar 'filelocking.enabled' em config.php para evitar esses problemas. Veja a  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a> para mais informações.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Bloqueio de arquivo transacional deve ser configurado para usar bloqueio com base em memória, não o travamento lento baseado em banco de dados padrão. Veja a  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentção ↗</a> para mais informação.",
    "System locale can not be set to a one which supports UTF-8." : "Localidade do sistema não pode ser definido como um que suporta UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Isso significa que pode haver problemas com certos caracteres nos nomes de arquivo.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Nós sugerimos a instalação dos pacotes necessários em seu sistema para suportar um dos seguintes locais: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se a sua instalação não estiver instalada na raiz do domínio e usa cron do sistema, pode haver problemas com a geração de URL. Para evitar esses problemas, por favor, defina a opção \"overwrite.cli.url\" em seu arquivo config.php para o caminho webroot de sua instalação (Sugestão: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite é usada como base de dados. Para instalações maiores recomendamos mudar para um backend de banco de dados diferente.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especialmente quando se utiliza o cliente de desktop para sincronização de arquivos o uso de SQLite é desencorajado.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Para migrar para outro banco de dados usar a ferramenta de linha de comando: 'occ db:convert-type', ou consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação ↗</a>.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Recomendamos ativar o cron do sistema como qualquer outro método cron tem possíveis implicações de desempenho e confiabilidade.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Não foi possível executar o cron via CLI. Os seguintes erros técnicos têm aparecido:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Por favor, verifique o <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">guias de instalação ↗</a>, e verificar se há erros ou avisos no <a href=\"#log-section\">log</a>.",
    "All checks passed." : "Todas as verificações passaram.",
    "System Status" : "Status do Sistema",
    "Tips & tricks" : "Dicas & Truques",
    "How to do backups" : "Como fazer backups",
    "Advanced monitoring" : "Monitoramento avançado",
    "Performance tuning" : "Aprimorando performance",
    "Improving the config.php" : "Melhorando o config.php",
    "Theming" : "Elaborar um tema",
    "Hardening and security guidance" : "Orientações de proteção e segurança",
    "Get the apps to sync your files" : "Obtenha apps para sincronizar seus arquivos",
    "Desktop client" : "Cliente Desktop",
    "Android app" : "App Android",
    "iOS app" : "App iOS",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Se você quiser apoiar o projeto\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">junte-se ao desenvolvimento</a>\n\t\t\tou\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">espalhe a palavra</a>!",
    "Show First Run Wizard again" : "Mostrar Assistente de Primeira Execução novamente",
    "Profile picture" : "Imagem para o perfil",
    "Upload new" : "Enviar nova foto",
    "Select from Files" : "Selecionar de Arquivos",
    "Remove image" : "Remover imagem",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 MB",
    "Picture provided by original account" : "Imagem fornecida por conta original",
    "Cancel" : "Cancelar",
    "Choose as profile picture" : "Escolha como imagem de perfil",
    "Full name" : "Nome completo",
    "No display name set" : "Nenhuma exibição de nome de configuração",
    "Email" : "E-mail",
    "Your email address" : "Seu endereço de e-mail",
    "Change email" : "Alterar e-mail",
    "Set email" : "Definir e-mail",
    "For password recovery and notifications" : "Para recuperação de senha e notificações",
    "No email address set" : "Nenhum endereço de email foi configurado",
    "You are member of the following groups:" : "Você é membro dos seguintes grupos:",
    "Password" : "Senha",
    "Unable to change your password" : "Não é possivel alterar a sua senha",
    "Current password" : "Senha atual",
    "New password" : "Nova senha",
    "Change password" : "Alterar senha",
    "Language" : "Idioma",
    "Help translate" : "Ajude a traduzir",
    "Unlimited" : "Ilimitado",
    "You are using %s of %s" : "Você está usando %s de %s",
    "You are using %s of %s (%s %%)" : "Você está usando %s de %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desenvolvido {communityopen}pela comunidade ownCloud{linkclose}, o {githubopen}código fonte{linkclose} está licenciado sob a {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Sessions" : "Sessões",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Estes são os clientes web, desktop e clientes móveis atualmente conectado ao seu ownCloud.",
    "Browser" : "Navegador",
    "Most recent activity" : "Atividade mais recente",
    "App passwords" : "Senhas de aplicativos",
    "You've linked these apps." : "Você vinculou esses aplicativos.",
    "Name" : "Nome",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "A senha do aplicativo é um código de acesso que dá ao aplicativo ou dispositivo permissões para acessar sua conta %s.",
    "App name" : "Nome do aplicativo",
    "Create new app password" : "Criar uma nova senha do aplicativo",
    "Use the credentials below to configure your app or device." : "Use as credenciais abaixo para configurar seu aplicativo ou dispositivo.",
    "Username" : "Nome de Usuário",
    "Done" : "Concluída",
    "Version" : "Versão",
    "Personal" : "Pessoal",
    "Admin" : "Admin",
    "Error" : "Erro",
    "No panels for this section." : "Nenhum painel para esta seção.",
    "Show enabled/disabled option" : "Mostrar opção ativada/desativada",
    "Show storage location" : "Mostrar localização de armazenamento",
    "Show last log in" : "Mostrar o último acesso",
    "Show user backend" : "Mostrar administrador do usuário",
    "Send email to new user" : "Enviar um email para o novo usuário",
    "Show email address" : "Mostrar o endereço de email",
    "E-Mail" : "E-Mail",
    "Create" : "Criar",
    "Admin Recovery Password" : "Recuperação da Senha do Administrador",
    "Enter the recovery password in order to recover the users files during password change" : "Digite a senha de recuperação para recuperar os arquivos dos usuários durante a mudança de senha.",
    "Add Group" : "Adicionar Grupo",
    "Group" : "Grupo",
    "Everyone" : "Para todos",
    "Admins" : "Administradores",
    "Default Quota" : "Quota Padrão",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor insira cota de armazenamento (ex: \"512\" ou \"12 GB\")",
    "Other" : "Outro",
    "Full Name" : "Nome Completo",
    "Group Admin for" : "Grupo Admin para",
    "Quota" : "Cota",
    "Storage Location" : "Local de Armazenamento",
    "User Backend" : "Administrador do Usuário",
    "Last Login" : "Último Login",
    "change full name" : "alterar nome completo",
    "set new password" : "definir nova senha",
    "change email address" : "Trocar o endereço de email",
    "Default" : "Padrão",
    "Change" : "Substituir ",
    "Share" : "Compartilhar",
    "installing and updating apps via the market or Federated Cloud Sharing" : "Instalando e atualizando aplicativos através do mercado ou Compartilhamento de Nuvem Federada",
    "White-listed Domains" : "Lista-Branca de Domínios",
    "Domain" : "Domínio",
    "Add Domain" : "Adicionar Domínio",
    "CORS" : "CORS",
    "User ID" : "ID do usuário",
    "Email address" : "Endereço de e-mail",
    "Invalid email address" : "Endereço de email inválido",
    "Extra field to display in autocomplete results" : "Campo extra para exibir em resultados de preenchimento automático",
    "Restrict users to only share with groups they are member of" : "Restrinja os usuários para compartilhar somente com grupos de que são membros",
    "Default user and group share permissions" : "Permissões padrão para usuários e grupos",
    "Enforce password protection for read-only links" : "Aplicar proteção de senha para links somente de leitura",
    "Enforce password protection for read & write links" : "Aplicar proteção de senha para links de leitura e gravação",
    "Enforce password protection for upload-only (File Drop) links" : "Aplicar proteção de senha para links de upload-only (Baixar Arquivo)",
    "You are using %s" : "Você está usando %s",
    "No Domains." : "Sem Domínios.",
    "Are you sure you want to remove this domain?" : "Tem certeza de que deseja remover esse domínio?",
    "Add" : "Adicionar",
    "Empty app name is not allowed." : "O nome do aplicativo vazio não é permitido.",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "O arquivo de configuração é somente leitura. Ajuste sua configuração editando o arquivo de configuração manualmente.",
    "Email changed successfully for {user}." : "E-mail alterado com sucesso para {user}.",
    "You are not a member of any groups." : "Você não é membro de nenhum grupo.",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "Em uma configuração em cluster, certifique-se de sincronizar o arquivo config.php em todos os nós.",
    "These are the web, desktop and mobile clients currently logged in to your %s." : "Estes são os clientes Web com dispositivos móveis e desktop, atualmente conectados ao seu %s.",
    "Automatically accept new incoming local user shares" : "Aceitar automaticamente novos compartilhamentos recebidos de usuários locais",
    "Legal" : "Legal",
    "Imprint URL:" : "URL para impressão:",
    "Imprint URL" : "URL de impressão:",
    "Privacy Policy URL:" : "Política de Privacidade para URL:",
    "Privacy Policy URL" : "Política de Privacidade para URL:",
    "App passwords / tokens" : "Senhas/tokens de aplicativo",
    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "Senhas de aplicativos ou tokens são códigos de acesso que fornecem permissões de aplicativo ou dispositivo para acessar sua %s conta.",
    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Use-os como uma medida de segurança para ocultar sua senha real, que você pode usar somente para o login da interface da web.",
    "Create new app passcode" : "Criar nova senha do aplicativo",
    "Password / Token" : "Senha/Token",
    "Owner language" : "Idioma do proprietário",
    "Language used for public mail notifications for shared files" : "Idioma usado para notificações de correio público para arquivos compartilhados",
    "Wrong current password" : "Senha atual incorreta",
    "The new password cannot be the same as the previous one" : "A nova senha não pode ser a mesma que a anterior"
},
"nplurals=2; plural=(n > 1);");
